@@ -2,6 +2,8 @@ from ekp_sdk.services.cache_service import CacheService
 from ekp_sdk.services.client_service import ClientService
 from ekp_sdk.services.coingecko_service import CoingeckoService
 from ekp_sdk.services.etherscan_service import EtherscanService
+from ekp_sdk.services.limiter import Limiter
 from ekp_sdk.services.redis_client import RedisClient
 from ekp_sdk.services.rest_client import RestClient
+from ekp_sdk.services.transaction_sync_service import TransactionSyncService
 from ekp_sdk.services.web3_service import Web3Service
